@@ -19,9 +19,9 @@ do
 		found=`grep -c -e "$line2" $TARGET_NEW`
 	
 		if [ "$found" == "0" ]; then
-#			echo -E $line1; # >> $TARGET_NEW
-			echo -E $line2; # >> $TARGET_NEW
-#			echo -E $line3; # >> $TARGET_NEW
+#			/bin/echo $line1; # >> $TARGET_NEW
+			/bin/echo $line2; # >> $TARGET_NEW
+#			/bin/echo $line3; # >> $TARGET_NEW
 		fi
 		
 	fi
